pub struct Detection<'s> {
pub rules: HashSet<Cow<'s, str>>,
pub tags: HashSet<Cow<'s, str>>,
pub attack: HashSet<Cow<'s, str>>,
pub actions: HashSet<Cow<'s, str>>,
pub severity: u8,
}Expand description
Structure holding information about the detection rules matching the Event.
Fields
rules: HashSet<Cow<'s, str>>Union of the rule names matching the event
Union of tags defined in the rules matching the event
attack: HashSet<Cow<'s, str>>Union of attack ids defined in the rules matching the event
actions: HashSet<Cow<'s, str>>Union of actions defined in the rules matching the event
severity: u8Sum of all matching rules’ severity (bounded to MAX_SEVERITY)